@@ -295,6 +295,7 @@ PsychError PsychModuleInit(void)
     PsychErrorExit(PsychRegister("PanelFitter", &SCREENPanelFitter));
     PsychErrorExit(PsychRegister("TextTransform", &SCREENTextTransform));
     PsychErrorExit(PsychRegister("ConstrainCursor", &SCREENConstrainCursor));
+    PsychErrorExit(PsychRegister("ReadHDRImage", &SCREENReadHDRImage));
 
     PsychSetModuleAuthorByInitials("awi");
     PsychSetModuleAuthorByInitials("dhb");
@@ -326,13 +327,3 @@ PsychError PsychModuleInit(void)
 
     return(PsychError_none);
 }
-
-#if PSYCH_LANGUAGE == PSYCH_PYTHON
-
-PyMODINIT_FUNC
-initScreen(void)
-{
-    PsychPythonInit("Screen");
-}
-
-#endif
