@@ -13,6 +13,9 @@
 % 4/13/17   dhb     Switch default cone type to Stockman-Sharpe.
 %                   Demonstrate conversion from cone contrast coords to
 %                   DKL, code at end.
+% 8/21/21   dhb     Added a few more checks and comments.  Made some of the
+%                   numbers less generic, on the view that testing is more
+%                   robust in such cases.
 
 %% Clear
 clear; close all
@@ -23,7 +26,7 @@ whichCones = 'StockmanSharpe';
 
 % Load spectral data and set calibration file
 switch (whichCones)
-	case 'SmithPokorny',
+	case 'SmithPokorny'
 		load T_cones_sp
 		load T_xyzJuddVos
 		S_cones = S_cones_sp;
@@ -39,6 +42,8 @@ switch (whichCones)
 		T_Y = 683*T_ss2000_Y2;
 		S_Y = S_ss2000_Y2;
 		T_Y = SplineCmf(S_Y,T_Y,S_cones);
+    otherwise
+        error('Unknown cone fundamentals specified')
 end
 cal = LoadCalFile('PTB3TestCal');
 calLMS = SetSensorColorSpace(cal,T_cones,S_cones);
@@ -46,8 +51,8 @@ calLMS = SetGammaMethod(calLMS,1);
 calLum = SetSensorColorSpace(cal,T_Y,S_Y);
 
 %% Define background.  Here we just take the
-% monitor mid-point.
-bgLMS = PrimaryToSensor(calLMS,[0.5 0.5 0.5]');
+% something near the monitor mid-point.
+bgLMS = PrimaryToSensor(calLMS,[0.4 0.5 0.3]');
 
 %% Basic transformation matrices.  ComputeDKL_M() does the work.
 %
@@ -57,14 +62,24 @@ bgLMS = PrimaryToSensor(calLMS,[0.5 0.5 0.5]');
 [M_ConeIncToDKL,LMLumWeights] = ComputeDKL_M(bgLMS,T_cones,T_Y);
 M_DKLToConeInc = inv(M_ConeIncToDKL);
 
-%% Find incremental cone directions corresponding to DKL isoluminant directions.
+%% Find incremental cone directions corresponding to DKL  directions.
+lumConeInc = M_DKLToConeInc*[1 0 0]';
 rgConeInc = M_DKLToConeInc*[0 1 0]';
 sConeInc = M_DKLToConeInc*[0 0 1]';
 
-% These directions are not scaled in an interesting way,
-% need to scale them.  Here we'll find units so that 
-% a unit excursion in the two directions brings us to
-% the edge of the monitor gamut, with a little headroom.
+% These directions should (and do last I checked) have unit pooled cone contrast,
+% the way that the matrix M is scaled by ComputeDKL_M.
+lumPooled = norm(lumConeInc ./ bgLMS);
+rgPooled = norm(rgConeInc ./ bgLMS);
+sPooled = norm(sConeInc ./ bgLMS);
+fprintf('Pooled cone contrast for unit DKL directions with initial scaling: %0.3g %0.3g %0.3g\n', ...
+    lumPooled, rgPooled, sPooled);
+
+% The pooled cone contrast scaling convention implemented by ComputeDKL_M
+% is fine, but one might also want to scale in some other way, say so that
+% a unit step was just within the monitor gamut.  Here we compute such
+% scale factors for the rg and s directions.  The work is done by routine
+% MaximizeGamutContrast.
 bgPrimary = SensorToPrimary(calLMS,bgLMS);
 rgPrimaryInc = SensorToPrimary(calLMS,rgConeInc+bgLMS)-bgPrimary;
 sPrimaryInc = SensorToPrimary(calLMS,sConeInc+bgLMS)-bgPrimary;
@@ -129,7 +144,7 @@ figure; clf; image(theImage);
 %% What if we want to convert between cone contrast coordinates and DKL?
 
 % Also, let's optionally scale the cones so that they sum to luminance
-SCALE_LMSUMTOLUM = true;
+SCALE_LMSUMTOLUM = false;
 if (SCALE_LMSUMTOLUM)
     T_cones(1,:) = T_cones(1,:)*LMLumWeights(1);
     T_cones(2,:) = T_cones(2,:)*LMLumWeights(2);
@@ -139,7 +154,7 @@ end
 % but you can try different values here.  Note that if you're mucking
 % with the scaling of the cones, then holding this vector fixed across
 % two different cone scalings is not holding the actual background fixed.
-bgLMS = [0.2 0.2 0.2]';
+bgLMS = [0.2 0.3 0.25]';
 
 % Compute matrix that goes into DKL
 [M_ConeIncToDKL,LMLumWeights] = ComputeDKL_M(bgLMS,T_cones,T_Y);
@@ -169,6 +184,8 @@ theBYDKL = M_ConeIncToDKL*M_ConeContrastToConeInc*theBYConeContrast;
 % Choose a scaling matrix so that the first DKL length is the luminance
 % contrast, the second is the average of the LM contrasts for the
 % isoluminant red-green direciton, and the third is the S cone contrast.
+% You may have detected by now that there are lots of ways to choose the
+% scaling of these directions. 
 M_scaleDKLForContrastInput = diag(1./[theIsochromaticDKL(1)/theBaseConeContrast theRedGreenDKL(2)/meanRedGreenAbsConeContrast theBYDKL(3)/theBaseConeContrast]);
 M_coneContrastToDKL = M_scaleDKLForContrastInput*M_ConeIncToDKL*M_ConeContrastToConeInc;
 
