@@ -155,6 +155,13 @@ try
         pixelFormat = [];
     end
 
+    % On ARM set the default pixelFormat to 6 for shader based decode.
+    % On a RaspberryPi-4 this makes a world of difference when playing
+    % HD movies, between slow-motion 2 fps and proper 24 fps playback.
+    if isempty(pixelFormat) && IsARM
+        pixelFormat = 6;
+    end
+
     % Use default maxThreads if none specified:
     if nargin < 6
         maxThreads = [];
