@@ -42,6 +42,16 @@ function MorphDemo(textureon, dotson, normalson, stereomode)
 morphnormals = 1;
 global win;
 
+% Octave's new plotting backend 'fltk' interferes with Screen(),
+% due to internal use of OpenGL. Problem is it changes the
+% bound OpenGL rendering context behind our back and we
+% don't protect ourselves against this yet. Switch plotting backend
+% to good'ol gnuplot to work around this issue until we fix it properly
+% inside Screen():
+if IsOctave && exist('graphics_toolkit')
+    graphics_toolkit ('gnuplot');
+end
+
 % Is the script running in OpenGL Psychtoolbox?
 AssertOpenGL;
 
@@ -235,8 +245,8 @@ glMatrixMode(GL.PROJECTION);
 glLoadIdentity;
 
 if ~isempty(hmd)
-  % HMD in use: Get optimal projection matrix from its driver:
-  glLoadMatrixd(PsychVRHMD('GetStaticRenderParameters', hmd));
+  % HMD in use: Get optimal projection matrices from its driver:
+  [projMatrix{1}, projMatrix{2}] = PsychVRHMD('GetStaticRenderParameters', hmd);
 else
   % Field of view is +/- 25 degrees from line of sight. Objects close than
   % 0.1 distance units or farther away than 200 distance units get clipped
@@ -350,6 +360,9 @@ while ((GetSecs - t) < 60)
       glLoadIdentity;
       gluLookAt(-eye_halfdist, 0, zz, 0, 0, 0, 0, 1, 0);
     else
+      glMatrixMode(GL.PROJECTION);
+      glLoadMatrixd(projMatrix{1});
+      glMatrixMode(GL.MODELVIEW);
       glLoadMatrixd(state.modelView{1});
     end
 
@@ -375,6 +388,9 @@ while ((GetSecs - t) < 60)
             glLoadIdentity;
             gluLookAt(+eye_halfdist, 0, zz, 0, 0, 0, 0, 1, 0);
         else
+            glMatrixMode(GL.PROJECTION);
+            glLoadMatrixd(projMatrix{2});
+            glMatrixMode(GL.MODELVIEW);
             glLoadMatrixd(state.modelView{2});
         end
 
