@@ -453,7 +453,7 @@ if isempty(isbuggyatidriver)
     isbuggyatidriver = 0;
 
     % ATI X1000 series on OS/X?
-    if ~isempty(findstr(glGetString(GL.RENDERER), 'Radeon X1')) && IsOSX
+    if ~isempty(strfind(glGetString(GL.RENDERER), 'Radeon X1')) && IsOSX
         % OS/X 10.4.x ATI driver is buggy, but not 10.5.5 and later.
         compinfo = Screen('Computer');
         osrelease = sscanf(compinfo.system, '%*s %*s %*i.%i.%i');
@@ -498,14 +498,14 @@ if isempty(gpubasedmorphing)
     gpubasedmorphing = 0;
 
     % Check if all OpenGL extensions for GPU based morphing are available:
-    if ~isempty(findstr(glGetString(GL.EXTENSIONS), '_vertex_buffer_object')) && ...
-            ~isempty(findstr(glGetString(GL.EXTENSIONS), '_pixel_buffer_object')) && ...
-            ~isempty(findstr(glGetString(GL.EXTENSIONS), '_framebuffer_object')) && ...
-            ~isempty(findstr(glGetString(GL.EXTENSIONS), 'GL_ARB_shading_language')) && ...
-            ~isempty(findstr(glGetString(GL.EXTENSIONS), 'GL_ARB_shader_objects')) && ...
-            ~isempty(findstr(glGetString(GL.EXTENSIONS), 'GL_ARB_fragment_shader')) && ...
-            (~isempty(findstr(glGetString(GL.EXTENSIONS), 'GL_APPLE_float_pixels')) || ...
-             ~isempty(findstr(glGetString(GL.EXTENSIONS), '_color_buffer_float')))
+    if ~isempty(strfind(glGetString(GL.EXTENSIONS), '_vertex_buffer_object')) && ...
+            ~isempty(strfind(glGetString(GL.EXTENSIONS), '_pixel_buffer_object')) && ...
+            ~isempty(strfind(glGetString(GL.EXTENSIONS), '_framebuffer_object')) && ...
+            ~isempty(strfind(glGetString(GL.EXTENSIONS), 'GL_ARB_shading_language')) && ...
+            ~isempty(strfind(glGetString(GL.EXTENSIONS), 'GL_ARB_shader_objects')) && ...
+            ~isempty(strfind(glGetString(GL.EXTENSIONS), 'GL_ARB_fragment_shader')) && ...
+            (~isempty(strfind(glGetString(GL.EXTENSIONS), 'GL_APPLE_float_pixels')) || ...
+             ~isempty(strfind(glGetString(GL.EXTENSIONS), '_color_buffer_float')))
         % Test passed: All required extensions are supported.
 
         % Check if at least minimal imaging pipeline is active. Otherwise
@@ -552,7 +552,7 @@ end
 
 % Check if hardware supports glDrawRangeElements():
 if isempty(drawrangeelements)
-    if isempty(findstr(glGetString(GL.EXTENSIONS), 'GL_EXT_draw_range_elements'))
+    if isempty(strfind(glGetString(GL.EXTENSIONS), 'GL_EXT_draw_range_elements'))
         % No glDrawRangeElements() support.
         drawrangeelements = 0;
     else
