@@ -6,7 +6,7 @@
 % 6/16/03  dhb  Wrote it.
 
 % Clear
-clear all; close all;
+clear; close all;
 
 % Fill in some structs
 theStructs(1).field1 = 'joe';
@@ -33,3 +33,6 @@ newStructs = ReadStructsFromText('foo.txt');
 % Delete test file.
 delete foo.txt
 
+if ~isequal(newStructs, theStructs)
+  warning('Read back structs from previously written file disagree, but should be identical!');
+end
